@@ -1,38 +1,68 @@
 var NAVTREEINDEX90 =
 {
-"da/d47/classisc_1_1util_1_1PIDFile.html#a6037f9902f32f7adb597eaa8540aa832":[7,0,1,26,27,6],
-"da/d47/classisc_1_1util_1_1PIDFile.html#a6037f9902f32f7adb597eaa8540aa832":[6,0,2,28,28,6],
-"da/d47/classisc_1_1util_1_1PIDFile.html#a8fdbc9738de2f5ae361e27b87c9bf421":[6,0,2,28,28,3],
-"da/d47/classisc_1_1util_1_1PIDFile.html#a8fdbc9738de2f5ae361e27b87c9bf421":[7,0,1,26,27,3],
-"da/d47/classisc_1_1util_1_1PIDFile.html#ac464be019669fde673d1966d0b825531":[7,0,1,26,27,4],
-"da/d47/classisc_1_1util_1_1PIDFile.html#ac464be019669fde673d1966d0b825531":[6,0,2,28,28,4],
-"da/d47/classisc_1_1util_1_1PIDFile.html#af8bd1b04a95fd5715646d64c2c2b2b0e":[6,0,2,28,28,2],
-"da/d47/classisc_1_1util_1_1PIDFile.html#af8bd1b04a95fd5715646d64c2c2b2b0e":[7,0,1,26,27,2],
-"da/d4a/classisc_1_1dhcp_1_1IfaceNotFound.html":[7,0,1,9,120],
-"da/d4a/classisc_1_1dhcp_1_1IfaceNotFound.html":[6,0,2,11,120],
-"da/d4a/classisc_1_1dhcp_1_1IfaceNotFound.html#ad2c1f29523a169786922fb1ebbfe8d19":[7,0,1,9,120,0],
-"da/d4a/classisc_1_1dhcp_1_1IfaceNotFound.html#ad2c1f29523a169786922fb1ebbfe8d19":[6,0,2,11,120,0],
-"da/d4a/library__handle_8h.html":[8,0,0,2,16,20],
-"da/d4a/library__handle_8h.html#a25e0b3cae1cc1b876313797a010e2af5":[8,0,0,2,16,20,1],
-"da/d4a/library__handle_8h_source.html":[8,0,0,2,16,20],
-"da/d4d/cfg__subnets4_8h.html":[8,0,0,2,12,47],
-"da/d4d/cfg__subnets4_8h.html#aa2c6e83eb725fec623f9e7ec0d10bb36":[8,0,0,2,12,47,1],
-"da/d4d/cfg__subnets4_8h.html#aa5fe066be44f80fe8bb496c74605f50b":[8,0,0,2,12,47,2],
-"da/d4d/cfg__subnets4_8h_source.html":[8,0,0,2,12,47],
-"da/d4e/classify_8cc.html":[8,0,0,2,10,0],
-"da/d4e/classify_8cc_source.html":[8,0,0,2,10,0],
-"da/d4e/classisc_1_1dhcp_1_1HostReservationsListParser.html":[6,0,2,11,112],
-"da/d4e/classisc_1_1dhcp_1_1HostReservationsListParser.html":[7,0,1,9,112],
-"da/d4e/classisc_1_1dhcp_1_1HostReservationsListParser.html#ae52d4c05a112e608568704b31614deab":[7,0,1,9,112,0],
-"da/d4e/classisc_1_1dhcp_1_1HostReservationsListParser.html#ae52d4c05a112e608568704b31614deab":[6,0,2,11,112,0],
-"da/d4f/classisc_1_1d2_1_1NameRemoveTransaction.html":[6,0,2,7,39],
+"da/d42/classisc_1_1hooks_1_1PointerConverter.html#a3c15a763c12052b43e88164d7269326c":[6,0,2,17,21,7],
+"da/d42/classisc_1_1hooks_1_1PointerConverter.html#a51379728e980efcbd0aecdbb9dcd0087":[6,0,2,17,21,8],
+"da/d42/classisc_1_1hooks_1_1PointerConverter.html#a51379728e980efcbd0aecdbb9dcd0087":[7,0,1,15,21,8],
+"da/d42/classisc_1_1hooks_1_1PointerConverter.html#a7886eca4d961c334e927ae42f9936711":[6,0,2,17,21,3],
+"da/d42/classisc_1_1hooks_1_1PointerConverter.html#a7886eca4d961c334e927ae42f9936711":[7,0,1,15,21,3],
+"da/d42/classisc_1_1hooks_1_1PointerConverter.html#ab4bb2506e0c550bad8c99beb7d049b9d":[6,0,2,17,21,2],
+"da/d42/classisc_1_1hooks_1_1PointerConverter.html#ab4bb2506e0c550bad8c99beb7d049b9d":[7,0,1,15,21,2],
+"da/d42/classisc_1_1hooks_1_1PointerConverter.html#aea1abcc66a26500dbf4da62c701b02ba":[7,0,1,15,21,4],
+"da/d42/classisc_1_1hooks_1_1PointerConverter.html#aea1abcc66a26500dbf4da62c701b02ba":[6,0,2,17,21,4],
+"da/d42/classisc_1_1hooks_1_1PointerConverter.html#af14dedeb3aa65d4682b23f1d35666f27":[6,0,2,17,21,12],
+"da/d42/classisc_1_1hooks_1_1PointerConverter.html#af14dedeb3aa65d4682b23f1d35666f27":[7,0,1,15,21,12],
+"da/d42/classisc_1_1hooks_1_1PointerConverter.html#af7f47318f3af4ff8fb0905e3eebd7641":[7,0,1,15,21,11],
+"da/d42/classisc_1_1hooks_1_1PointerConverter.html#af7f47318f3af4ff8fb0905e3eebd7641":[6,0,2,17,21,11],
+"da/d45/tsigerror_8cc.html":[8,0,0,2,12,59],
+"da/d45/tsigerror_8cc.html#a20f1bf39fdbb47421aa4a1c708c7e9b1":[8,0,0,2,12,59,0],
+"da/d45/tsigerror_8cc_source.html":[8,0,0,2,12,59],
+"da/d46/logger__support_8cc.html":[8,0,0,2,17,25],
+"da/d46/logger__support_8cc.html#a1fc67842af7bd37128d1929843977f12":[8,0,0,2,17,25,3],
+"da/d46/logger__support_8cc.html#a68b02da6a370e2f24c61b7cf8bc76683":[8,0,0,2,17,25,0],
+"da/d46/logger__support_8cc.html#aa5b708ee892eac457ca486e5df5c9ee6":[8,0,0,2,17,25,1],
+"da/d46/logger__support_8cc.html#ad9a06fd788a1e3d706664a473598d376":[8,0,0,2,17,25,2],
+"da/d46/logger__support_8cc_source.html":[8,0,0,2,17,25],
+"da/d47/classisc_1_1util_1_1PIDFile.html":[6,0,2,28,30],
+"da/d47/classisc_1_1util_1_1PIDFile.html":[7,0,1,26,28],
+"da/d47/classisc_1_1util_1_1PIDFile.html#a2225450b7adf21909efe3794b0e44c71":[6,0,2,28,30,0],
+"da/d47/classisc_1_1util_1_1PIDFile.html#a2225450b7adf21909efe3794b0e44c71":[7,0,1,26,28,0],
+"da/d47/classisc_1_1util_1_1PIDFile.html#a2907edc89d04cb3f40803c8310600bda":[6,0,2,28,30,1],
+"da/d47/classisc_1_1util_1_1PIDFile.html#a2907edc89d04cb3f40803c8310600bda":[7,0,1,26,28,1],
+"da/d47/classisc_1_1util_1_1PIDFile.html#a4f67a57a7b16c9ab7bb9b390e40ed0ea":[7,0,1,26,28,5],
+"da/d47/classisc_1_1util_1_1PIDFile.html#a4f67a57a7b16c9ab7bb9b390e40ed0ea":[6,0,2,28,30,5],
+"da/d47/classisc_1_1util_1_1PIDFile.html#a6037f9902f32f7adb597eaa8540aa832":[7,0,1,26,28,6],
+"da/d47/classisc_1_1util_1_1PIDFile.html#a6037f9902f32f7adb597eaa8540aa832":[6,0,2,28,30,6],
+"da/d47/classisc_1_1util_1_1PIDFile.html#a8fdbc9738de2f5ae361e27b87c9bf421":[7,0,1,26,28,3],
+"da/d47/classisc_1_1util_1_1PIDFile.html#a8fdbc9738de2f5ae361e27b87c9bf421":[6,0,2,28,30,3],
+"da/d47/classisc_1_1util_1_1PIDFile.html#ac464be019669fde673d1966d0b825531":[7,0,1,26,28,4],
+"da/d47/classisc_1_1util_1_1PIDFile.html#ac464be019669fde673d1966d0b825531":[6,0,2,28,30,4],
+"da/d47/classisc_1_1util_1_1PIDFile.html#af8bd1b04a95fd5715646d64c2c2b2b0e":[7,0,1,26,28,2],
+"da/d47/classisc_1_1util_1_1PIDFile.html#af8bd1b04a95fd5715646d64c2c2b2b0e":[6,0,2,28,30,2],
+"da/d4a/classisc_1_1dhcp_1_1IfaceNotFound.html":[6,0,2,11,115],
+"da/d4a/classisc_1_1dhcp_1_1IfaceNotFound.html":[7,0,1,9,115],
+"da/d4a/classisc_1_1dhcp_1_1IfaceNotFound.html#ad2c1f29523a169786922fb1ebbfe8d19":[7,0,1,9,115,0],
+"da/d4a/classisc_1_1dhcp_1_1IfaceNotFound.html#ad2c1f29523a169786922fb1ebbfe8d19":[6,0,2,11,115,0],
+"da/d4a/library__handle_8h.html":[8,0,0,2,15,20],
+"da/d4a/library__handle_8h.html#a25e0b3cae1cc1b876313797a010e2af5":[8,0,0,2,15,20,1],
+"da/d4a/library__handle_8h_source.html":[8,0,0,2,15,20],
+"da/d4d/cfg__subnets4_8h.html":[8,0,0,2,11,48],
+"da/d4d/cfg__subnets4_8h.html#aa2c6e83eb725fec623f9e7ec0d10bb36":[8,0,0,2,11,48,1],
+"da/d4d/cfg__subnets4_8h.html#aa5fe066be44f80fe8bb496c74605f50b":[8,0,0,2,11,48,2],
+"da/d4d/cfg__subnets4_8h_source.html":[8,0,0,2,11,48],
+"da/d4e/classify_8cc.html":[8,0,0,2,9,0],
+"da/d4e/classify_8cc_source.html":[8,0,0,2,9,0],
+"da/d4e/classisc_1_1dhcp_1_1HostReservationsListParser.html":[7,0,1,9,107],
+"da/d4e/classisc_1_1dhcp_1_1HostReservationsListParser.html":[6,0,2,11,107],
+"da/d4e/classisc_1_1dhcp_1_1HostReservationsListParser.html#ae52d4c05a112e608568704b31614deab":[7,0,1,9,107,0],
+"da/d4e/classisc_1_1dhcp_1_1HostReservationsListParser.html#ae52d4c05a112e608568704b31614deab":[6,0,2,11,107,0],
 "da/d4f/classisc_1_1d2_1_1NameRemoveTransaction.html":[7,0,1,6,39],
-"da/d4f/classisc_1_1d2_1_1NameRemoveTransaction.html#a1cff38aa7fb60ec10e3f8e82cfc3cc56":[7,0,1,6,39,16],
+"da/d4f/classisc_1_1d2_1_1NameRemoveTransaction.html":[6,0,2,7,39],
 "da/d4f/classisc_1_1d2_1_1NameRemoveTransaction.html#a1cff38aa7fb60ec10e3f8e82cfc3cc56":[6,0,2,7,39,16],
+"da/d4f/classisc_1_1d2_1_1NameRemoveTransaction.html#a1cff38aa7fb60ec10e3f8e82cfc3cc56":[7,0,1,6,39,16],
 "da/d4f/classisc_1_1d2_1_1NameRemoveTransaction.html#a321bfb744b349aba5c898b7e3c855ca3":[7,0,1,6,39,5],
 "da/d4f/classisc_1_1d2_1_1NameRemoveTransaction.html#a321bfb744b349aba5c898b7e3c855ca3":[6,0,2,7,39,5],
-"da/d4f/classisc_1_1d2_1_1NameRemoveTransaction.html#a345dbe7614e18c4292e906f56963ab60":[6,0,2,7,39,8],
 "da/d4f/classisc_1_1d2_1_1NameRemoveTransaction.html#a345dbe7614e18c4292e906f56963ab60":[7,0,1,6,39,8],
+"da/d4f/classisc_1_1d2_1_1NameRemoveTransaction.html#a345dbe7614e18c4292e906f56963ab60":[6,0,2,7,39,8],
 "da/d4f/classisc_1_1d2_1_1NameRemoveTransaction.html#a3ba58f1d5085a52a06710f45b93af5c7":[7,0,1,6,39,9],
 "da/d4f/classisc_1_1d2_1_1NameRemoveTransaction.html#a3ba58f1d5085a52a06710f45b93af5c7":[6,0,2,7,39,9],
 "da/d4f/classisc_1_1d2_1_1NameRemoveTransaction.html#a3d40dae13910f92f0bc3974dfca2dce2":[6,0,2,7,39,4],
@@ -49,169 +79,169 @@ var NAVTREEINDEX90 =
 "da/d4f/classisc_1_1d2_1_1NameRemoveTransaction.html#a987b063843aebc800593c61d3c488aaa":[7,0,1,6,39,12],
 "da/d4f/classisc_1_1d2_1_1NameRemoveTransaction.html#aa53f8a74e5ea4f9db016f20f9d7adc64":[6,0,2,7,39,0],
 "da/d4f/classisc_1_1d2_1_1NameRemoveTransaction.html#aa53f8a74e5ea4f9db016f20f9d7adc64":[7,0,1,6,39,0],
-"da/d4f/classisc_1_1d2_1_1NameRemoveTransaction.html#aa72a4cf2e8388716122b0d75e683b337":[7,0,1,6,39,11],
 "da/d4f/classisc_1_1d2_1_1NameRemoveTransaction.html#aa72a4cf2e8388716122b0d75e683b337":[6,0,2,7,39,11],
-"da/d4f/classisc_1_1d2_1_1NameRemoveTransaction.html#ac9831769843e401ad8e8a023c5613956":[7,0,1,6,39,13],
+"da/d4f/classisc_1_1d2_1_1NameRemoveTransaction.html#aa72a4cf2e8388716122b0d75e683b337":[7,0,1,6,39,11],
 "da/d4f/classisc_1_1d2_1_1NameRemoveTransaction.html#ac9831769843e401ad8e8a023c5613956":[6,0,2,7,39,13],
-"da/d4f/classisc_1_1d2_1_1NameRemoveTransaction.html#ad6fdfcda40e8bd85d043f7cfc42646b7":[6,0,2,7,39,2],
+"da/d4f/classisc_1_1d2_1_1NameRemoveTransaction.html#ac9831769843e401ad8e8a023c5613956":[7,0,1,6,39,13],
 "da/d4f/classisc_1_1d2_1_1NameRemoveTransaction.html#ad6fdfcda40e8bd85d043f7cfc42646b7":[7,0,1,6,39,2],
+"da/d4f/classisc_1_1d2_1_1NameRemoveTransaction.html#ad6fdfcda40e8bd85d043f7cfc42646b7":[6,0,2,7,39,2],
 "da/d4f/classisc_1_1d2_1_1NameRemoveTransaction.html#ae10115850e285ccd018c1341e16dcd6c":[6,0,2,7,39,3],
 "da/d4f/classisc_1_1d2_1_1NameRemoveTransaction.html#ae10115850e285ccd018c1341e16dcd6c":[7,0,1,6,39,3],
-"da/d4f/classisc_1_1d2_1_1NameRemoveTransaction.html#aea05bb2341e22cb29af71e0c415222b5":[7,0,1,6,39,1],
 "da/d4f/classisc_1_1d2_1_1NameRemoveTransaction.html#aea05bb2341e22cb29af71e0c415222b5":[6,0,2,7,39,1],
-"da/d4f/classisc_1_1d2_1_1NameRemoveTransaction.html#af13161bec1cea602fdf417f37adbdec0":[6,0,2,7,39,7],
+"da/d4f/classisc_1_1d2_1_1NameRemoveTransaction.html#aea05bb2341e22cb29af71e0c415222b5":[7,0,1,6,39,1],
 "da/d4f/classisc_1_1d2_1_1NameRemoveTransaction.html#af13161bec1cea602fdf417f37adbdec0":[7,0,1,6,39,7],
-"da/d50/cfg__subnets4_8cc.html":[8,0,0,2,12,46],
-"da/d50/cfg__subnets4_8cc_source.html":[8,0,0,2,12,46],
-"da/d50/shared__networks__list__parser_8h.html":[8,0,0,2,12,1,25],
-"da/d50/shared__networks__list__parser_8h.html#a38723240abcc78cbeceeaaf97edfadda":[8,0,0,2,12,1,25,1],
-"da/d50/shared__networks__list__parser_8h.html#aba3a0e4c6736e255f36b0bfd90f3eff8":[8,0,0,2,12,1,25,2],
-"da/d50/shared__networks__list__parser_8h_source.html":[8,0,0,2,12,1,25],
-"da/d52/classisc_1_1dhcp_1_1NetworkStateImpl.html":[6,0,2,11,172],
-"da/d52/classisc_1_1dhcp_1_1NetworkStateImpl.html":[7,0,1,9,172],
-"da/d52/classisc_1_1dhcp_1_1NetworkStateImpl.html#a15a8e88eebf14566315d1d97382267f0":[7,0,1,9,172,13],
-"da/d52/classisc_1_1dhcp_1_1NetworkStateImpl.html#a15a8e88eebf14566315d1d97382267f0":[6,0,2,11,172,13],
-"da/d52/classisc_1_1dhcp_1_1NetworkStateImpl.html#a2082367758987dfeabf716dbb1d20a75":[6,0,2,11,172,4],
-"da/d52/classisc_1_1dhcp_1_1NetworkStateImpl.html#a2082367758987dfeabf716dbb1d20a75":[7,0,1,9,172,4],
-"da/d52/classisc_1_1dhcp_1_1NetworkStateImpl.html#a305f30a98e48cc8623c3328953661540":[7,0,1,9,172,11],
-"da/d52/classisc_1_1dhcp_1_1NetworkStateImpl.html#a305f30a98e48cc8623c3328953661540":[6,0,2,11,172,11],
-"da/d52/classisc_1_1dhcp_1_1NetworkStateImpl.html#a343e0d987bae99006aac4ec9c6de6848":[6,0,2,11,172,0],
-"da/d52/classisc_1_1dhcp_1_1NetworkStateImpl.html#a343e0d987bae99006aac4ec9c6de6848":[7,0,1,9,172,0],
-"da/d52/classisc_1_1dhcp_1_1NetworkStateImpl.html#a3b66aa031e68647da621ef90da79d95a":[7,0,1,9,172,8],
-"da/d52/classisc_1_1dhcp_1_1NetworkStateImpl.html#a3b66aa031e68647da621ef90da79d95a":[6,0,2,11,172,8],
-"da/d52/classisc_1_1dhcp_1_1NetworkStateImpl.html#a523ded7ba34a9df639e4febe17b358f3":[6,0,2,11,172,9],
-"da/d52/classisc_1_1dhcp_1_1NetworkStateImpl.html#a523ded7ba34a9df639e4febe17b358f3":[7,0,1,9,172,9],
-"da/d52/classisc_1_1dhcp_1_1NetworkStateImpl.html#a529d56c51e08be77d53a83d8b112edbf":[6,0,2,11,172,12],
-"da/d52/classisc_1_1dhcp_1_1NetworkStateImpl.html#a529d56c51e08be77d53a83d8b112edbf":[7,0,1,9,172,12],
-"da/d52/classisc_1_1dhcp_1_1NetworkStateImpl.html#a59d7828b78380ca3f0de49b42e074a31":[7,0,1,9,172,3],
-"da/d52/classisc_1_1dhcp_1_1NetworkStateImpl.html#a59d7828b78380ca3f0de49b42e074a31":[6,0,2,11,172,3],
-"da/d52/classisc_1_1dhcp_1_1NetworkStateImpl.html#a66c2a8b477e1008da027ad4dbd1d4f9f":[7,0,1,9,172,14],
-"da/d52/classisc_1_1dhcp_1_1NetworkStateImpl.html#a66c2a8b477e1008da027ad4dbd1d4f9f":[6,0,2,11,172,14],
-"da/d52/classisc_1_1dhcp_1_1NetworkStateImpl.html#a77ad629cb4f6bff5f4520e7360429693":[7,0,1,9,172,7],
-"da/d52/classisc_1_1dhcp_1_1NetworkStateImpl.html#a77ad629cb4f6bff5f4520e7360429693":[6,0,2,11,172,7],
-"da/d52/classisc_1_1dhcp_1_1NetworkStateImpl.html#a919f5d7e7d90bdef19e35e1b8878b262":[7,0,1,9,172,5],
-"da/d52/classisc_1_1dhcp_1_1NetworkStateImpl.html#a919f5d7e7d90bdef19e35e1b8878b262":[6,0,2,11,172,5],
-"da/d52/classisc_1_1dhcp_1_1NetworkStateImpl.html#a9fba448ad91e2c061416704a9f3eae89":[6,0,2,11,172,10],
-"da/d52/classisc_1_1dhcp_1_1NetworkStateImpl.html#a9fba448ad91e2c061416704a9f3eae89":[7,0,1,9,172,10],
-"da/d52/classisc_1_1dhcp_1_1NetworkStateImpl.html#ac9e6a9cdd04b6de7e229757a3fdfe85c":[6,0,2,11,172,2],
-"da/d52/classisc_1_1dhcp_1_1NetworkStateImpl.html#ac9e6a9cdd04b6de7e229757a3fdfe85c":[7,0,1,9,172,2],
-"da/d52/classisc_1_1dhcp_1_1NetworkStateImpl.html#acf0a8e6bef863a919f49955d9e146a5f":[6,0,2,11,172,1],
-"da/d52/classisc_1_1dhcp_1_1NetworkStateImpl.html#acf0a8e6bef863a919f49955d9e146a5f":[7,0,1,9,172,1],
-"da/d52/classisc_1_1dhcp_1_1NetworkStateImpl.html#af3dea84ec722f1ec83cad930fa935951":[6,0,2,11,172,6],
-"da/d52/classisc_1_1dhcp_1_1NetworkStateImpl.html#af3dea84ec722f1ec83cad930fa935951":[7,0,1,9,172,6],
-"da/d52/structisc_1_1db_1_1DB__LOG__INFO.html":[6,0,2,9,19],
-"da/d52/structisc_1_1db_1_1DB__LOG__INFO.html":[7,0,1,8,19],
-"da/d52/structisc_1_1db_1_1DB__LOG__INFO.html#ab369f02f08c5246cebb04d5278ec0b07":[6,0,2,9,19,0],
-"da/d52/structisc_1_1db_1_1DB__LOG__INFO.html#ab369f02f08c5246cebb04d5278ec0b07":[7,0,1,8,19,0],
+"da/d4f/classisc_1_1d2_1_1NameRemoveTransaction.html#af13161bec1cea602fdf417f37adbdec0":[6,0,2,7,39,7],
+"da/d50/cfg__subnets4_8cc.html":[8,0,0,2,11,47],
+"da/d50/cfg__subnets4_8cc_source.html":[8,0,0,2,11,47],
+"da/d50/shared__networks__list__parser_8h.html":[8,0,0,2,11,0,25],
+"da/d50/shared__networks__list__parser_8h.html#a38723240abcc78cbeceeaaf97edfadda":[8,0,0,2,11,0,25,1],
+"da/d50/shared__networks__list__parser_8h.html#aba3a0e4c6736e255f36b0bfd90f3eff8":[8,0,0,2,11,0,25,2],
+"da/d50/shared__networks__list__parser_8h_source.html":[8,0,0,2,11,0,25],
+"da/d52/classisc_1_1dhcp_1_1NetworkStateImpl.html":[6,0,2,11,168],
+"da/d52/classisc_1_1dhcp_1_1NetworkStateImpl.html":[7,0,1,9,168],
+"da/d52/classisc_1_1dhcp_1_1NetworkStateImpl.html#a15a8e88eebf14566315d1d97382267f0":[7,0,1,9,168,13],
+"da/d52/classisc_1_1dhcp_1_1NetworkStateImpl.html#a15a8e88eebf14566315d1d97382267f0":[6,0,2,11,168,13],
+"da/d52/classisc_1_1dhcp_1_1NetworkStateImpl.html#a2082367758987dfeabf716dbb1d20a75":[6,0,2,11,168,4],
+"da/d52/classisc_1_1dhcp_1_1NetworkStateImpl.html#a2082367758987dfeabf716dbb1d20a75":[7,0,1,9,168,4],
+"da/d52/classisc_1_1dhcp_1_1NetworkStateImpl.html#a305f30a98e48cc8623c3328953661540":[7,0,1,9,168,11],
+"da/d52/classisc_1_1dhcp_1_1NetworkStateImpl.html#a305f30a98e48cc8623c3328953661540":[6,0,2,11,168,11],
+"da/d52/classisc_1_1dhcp_1_1NetworkStateImpl.html#a343e0d987bae99006aac4ec9c6de6848":[7,0,1,9,168,0],
+"da/d52/classisc_1_1dhcp_1_1NetworkStateImpl.html#a343e0d987bae99006aac4ec9c6de6848":[6,0,2,11,168,0],
+"da/d52/classisc_1_1dhcp_1_1NetworkStateImpl.html#a3b66aa031e68647da621ef90da79d95a":[6,0,2,11,168,8],
+"da/d52/classisc_1_1dhcp_1_1NetworkStateImpl.html#a3b66aa031e68647da621ef90da79d95a":[7,0,1,9,168,8],
+"da/d52/classisc_1_1dhcp_1_1NetworkStateImpl.html#a523ded7ba34a9df639e4febe17b358f3":[6,0,2,11,168,9],
+"da/d52/classisc_1_1dhcp_1_1NetworkStateImpl.html#a523ded7ba34a9df639e4febe17b358f3":[7,0,1,9,168,9],
+"da/d52/classisc_1_1dhcp_1_1NetworkStateImpl.html#a529d56c51e08be77d53a83d8b112edbf":[7,0,1,9,168,12],
+"da/d52/classisc_1_1dhcp_1_1NetworkStateImpl.html#a529d56c51e08be77d53a83d8b112edbf":[6,0,2,11,168,12],
+"da/d52/classisc_1_1dhcp_1_1NetworkStateImpl.html#a59d7828b78380ca3f0de49b42e074a31":[6,0,2,11,168,3],
+"da/d52/classisc_1_1dhcp_1_1NetworkStateImpl.html#a59d7828b78380ca3f0de49b42e074a31":[7,0,1,9,168,3],
+"da/d52/classisc_1_1dhcp_1_1NetworkStateImpl.html#a66c2a8b477e1008da027ad4dbd1d4f9f":[7,0,1,9,168,14],
+"da/d52/classisc_1_1dhcp_1_1NetworkStateImpl.html#a66c2a8b477e1008da027ad4dbd1d4f9f":[6,0,2,11,168,14],
+"da/d52/classisc_1_1dhcp_1_1NetworkStateImpl.html#a77ad629cb4f6bff5f4520e7360429693":[7,0,1,9,168,7],
+"da/d52/classisc_1_1dhcp_1_1NetworkStateImpl.html#a77ad629cb4f6bff5f4520e7360429693":[6,0,2,11,168,7],
+"da/d52/classisc_1_1dhcp_1_1NetworkStateImpl.html#a919f5d7e7d90bdef19e35e1b8878b262":[7,0,1,9,168,5],
+"da/d52/classisc_1_1dhcp_1_1NetworkStateImpl.html#a919f5d7e7d90bdef19e35e1b8878b262":[6,0,2,11,168,5],
+"da/d52/classisc_1_1dhcp_1_1NetworkStateImpl.html#a9fba448ad91e2c061416704a9f3eae89":[7,0,1,9,168,10],
+"da/d52/classisc_1_1dhcp_1_1NetworkStateImpl.html#a9fba448ad91e2c061416704a9f3eae89":[6,0,2,11,168,10],
+"da/d52/classisc_1_1dhcp_1_1NetworkStateImpl.html#ac9e6a9cdd04b6de7e229757a3fdfe85c":[7,0,1,9,168,2],
+"da/d52/classisc_1_1dhcp_1_1NetworkStateImpl.html#ac9e6a9cdd04b6de7e229757a3fdfe85c":[6,0,2,11,168,2],
+"da/d52/classisc_1_1dhcp_1_1NetworkStateImpl.html#acf0a8e6bef863a919f49955d9e146a5f":[7,0,1,9,168,1],
+"da/d52/classisc_1_1dhcp_1_1NetworkStateImpl.html#acf0a8e6bef863a919f49955d9e146a5f":[6,0,2,11,168,1],
+"da/d52/classisc_1_1dhcp_1_1NetworkStateImpl.html#af3dea84ec722f1ec83cad930fa935951":[6,0,2,11,168,6],
+"da/d52/classisc_1_1dhcp_1_1NetworkStateImpl.html#af3dea84ec722f1ec83cad930fa935951":[7,0,1,9,168,6],
+"da/d52/structisc_1_1db_1_1DB__LOG__INFO.html":[6,0,2,9,12],
+"da/d52/structisc_1_1db_1_1DB__LOG__INFO.html":[7,0,1,8,12],
+"da/d52/structisc_1_1db_1_1DB__LOG__INFO.html#ab369f02f08c5246cebb04d5278ec0b07":[7,0,1,8,12,0],
+"da/d52/structisc_1_1db_1_1DB__LOG__INFO.html#ab369f02f08c5246cebb04d5278ec0b07":[6,0,2,9,12,0],
 "da/d53/classisc_1_1config_1_1CmdResponseCreator.html":[7,0,1,4,5],
 "da/d53/classisc_1_1config_1_1CmdResponseCreator.html":[6,0,2,5,5],
-"da/d53/classisc_1_1config_1_1CmdResponseCreator.html#a410ea5c59a5d230792b5697a72e86b4d":[7,0,1,4,5,4],
-"da/d53/classisc_1_1config_1_1CmdResponseCreator.html#a410ea5c59a5d230792b5697a72e86b4d":[6,0,2,5,5,4],
-"da/d53/classisc_1_1config_1_1CmdResponseCreator.html#a6f4d9ff22e38052dc2e508470d85a374":[6,0,2,5,5,0],
+"da/d53/classisc_1_1config_1_1CmdResponseCreator.html#a1e1c58566e91cc67193ff44fbfb6db89":[7,0,1,4,5,4],
+"da/d53/classisc_1_1config_1_1CmdResponseCreator.html#a1e1c58566e91cc67193ff44fbfb6db89":[6,0,2,5,5,4],
 "da/d53/classisc_1_1config_1_1CmdResponseCreator.html#a6f4d9ff22e38052dc2e508470d85a374":[7,0,1,4,5,0],
+"da/d53/classisc_1_1config_1_1CmdResponseCreator.html#a6f4d9ff22e38052dc2e508470d85a374":[6,0,2,5,5,0],
 "da/d53/classisc_1_1config_1_1CmdResponseCreator.html#a7dc2898f7476eb562cad3ca87f8e5559":[7,0,1,4,5,2],
 "da/d53/classisc_1_1config_1_1CmdResponseCreator.html#a7dc2898f7476eb562cad3ca87f8e5559":[6,0,2,5,5,2],
-"da/d53/classisc_1_1config_1_1CmdResponseCreator.html#abefd9056adfb71b1f413b67e3dec6b68":[7,0,1,4,5,1],
 "da/d53/classisc_1_1config_1_1CmdResponseCreator.html#abefd9056adfb71b1f413b67e3dec6b68":[6,0,2,5,5,1],
+"da/d53/classisc_1_1config_1_1CmdResponseCreator.html#abefd9056adfb71b1f413b67e3dec6b68":[7,0,1,4,5,1],
 "da/d53/classisc_1_1config_1_1CmdResponseCreator.html#adb4fbd690c2b2e8ecdef43a775dc8964":[6,0,2,5,5,3],
 "da/d53/classisc_1_1config_1_1CmdResponseCreator.html#adb4fbd690c2b2e8ecdef43a775dc8964":[7,0,1,4,5,3],
 "da/d53/classisc_1_1http_1_1HttpMessageNonExistingHeader.html":[6,0,2,18,21],
 "da/d53/classisc_1_1http_1_1HttpMessageNonExistingHeader.html":[7,0,1,16,21],
-"da/d53/classisc_1_1http_1_1HttpMessageNonExistingHeader.html#a78e26d964cc52047239ebacd83ec3230":[7,0,1,16,21,0],
 "da/d53/classisc_1_1http_1_1HttpMessageNonExistingHeader.html#a78e26d964cc52047239ebacd83ec3230":[6,0,2,18,21,0],
-"da/d54/labeled__value_8cc.html":[8,0,0,2,24,15],
-"da/d54/labeled__value_8cc.html#a0c4c02be049f5b3e9c540b0d1ecdd2cb":[8,0,0,2,24,15,0],
-"da/d54/labeled__value_8cc_source.html":[8,0,0,2,24,15],
-"da/d57/classisc_1_1lease__cmds_1_1LeaseCmdsImpl.html":[7,0,1,17,3],
+"da/d53/classisc_1_1http_1_1HttpMessageNonExistingHeader.html#a78e26d964cc52047239ebacd83ec3230":[7,0,1,16,21,0],
+"da/d54/labeled__value_8cc.html":[8,0,0,2,23,19],
+"da/d54/labeled__value_8cc.html#a0c4c02be049f5b3e9c540b0d1ecdd2cb":[8,0,0,2,23,19,0],
+"da/d54/labeled__value_8cc_source.html":[8,0,0,2,23,19],
 "da/d57/classisc_1_1lease__cmds_1_1LeaseCmdsImpl.html":[6,0,2,19,3],
+"da/d57/classisc_1_1lease__cmds_1_1LeaseCmdsImpl.html":[7,0,1,17,3],
 "da/d57/classisc_1_1lease__cmds_1_1LeaseCmdsImpl.html#a0027e8ea8694120ff03b35d0a91bf793":[7,0,1,17,3,5],
 "da/d57/classisc_1_1lease__cmds_1_1LeaseCmdsImpl.html#a0027e8ea8694120ff03b35d0a91bf793":[6,0,2,19,3,5],
 "da/d57/classisc_1_1lease__cmds_1_1LeaseCmdsImpl.html#a04a57863fe603e32a64e9bc6c54ba086":[6,0,2,19,3,2],
 "da/d57/classisc_1_1lease__cmds_1_1LeaseCmdsImpl.html#a04a57863fe603e32a64e9bc6c54ba086":[7,0,1,17,3,2],
-"da/d57/classisc_1_1lease__cmds_1_1LeaseCmdsImpl.html#a11d323c203c656a67e3b2386fd07a2b1":[7,0,1,17,3,1],
 "da/d57/classisc_1_1lease__cmds_1_1LeaseCmdsImpl.html#a11d323c203c656a67e3b2386fd07a2b1":[6,0,2,19,3,1],
-"da/d57/classisc_1_1lease__cmds_1_1LeaseCmdsImpl.html#a1f3d977ae9b470dd0de195963ac79b85":[6,0,2,19,3,9],
+"da/d57/classisc_1_1lease__cmds_1_1LeaseCmdsImpl.html#a11d323c203c656a67e3b2386fd07a2b1":[7,0,1,17,3,1],
 "da/d57/classisc_1_1lease__cmds_1_1LeaseCmdsImpl.html#a1f3d977ae9b470dd0de195963ac79b85":[7,0,1,17,3,9],
-"da/d57/classisc_1_1lease__cmds_1_1LeaseCmdsImpl.html#a254ff69cec66927f739119572905102f":[6,0,2,19,3,17],
+"da/d57/classisc_1_1lease__cmds_1_1LeaseCmdsImpl.html#a1f3d977ae9b470dd0de195963ac79b85":[6,0,2,19,3,9],
 "da/d57/classisc_1_1lease__cmds_1_1LeaseCmdsImpl.html#a254ff69cec66927f739119572905102f":[7,0,1,17,3,17],
+"da/d57/classisc_1_1lease__cmds_1_1LeaseCmdsImpl.html#a254ff69cec66927f739119572905102f":[6,0,2,19,3,17],
 "da/d57/classisc_1_1lease__cmds_1_1LeaseCmdsImpl.html#a2a9333317d367b2f612d469d310789c9":[7,0,1,17,3,12],
 "da/d57/classisc_1_1lease__cmds_1_1LeaseCmdsImpl.html#a2a9333317d367b2f612d469d310789c9":[6,0,2,19,3,12],
 "da/d57/classisc_1_1lease__cmds_1_1LeaseCmdsImpl.html#a30f63f42c8d7ffd34617748935de78dd":[7,0,1,17,3,21],
 "da/d57/classisc_1_1lease__cmds_1_1LeaseCmdsImpl.html#a30f63f42c8d7ffd34617748935de78dd":[6,0,2,19,3,21],
-"da/d57/classisc_1_1lease__cmds_1_1LeaseCmdsImpl.html#a4345b78877baed234741a706bc3c8a78":[7,0,1,17,3,3],
 "da/d57/classisc_1_1lease__cmds_1_1LeaseCmdsImpl.html#a4345b78877baed234741a706bc3c8a78":[6,0,2,19,3,3],
+"da/d57/classisc_1_1lease__cmds_1_1LeaseCmdsImpl.html#a4345b78877baed234741a706bc3c8a78":[7,0,1,17,3,3],
 "da/d57/classisc_1_1lease__cmds_1_1LeaseCmdsImpl.html#a43c7d2663aceb461097c821a8ec8c336":[7,0,1,17,3,18],
 "da/d57/classisc_1_1lease__cmds_1_1LeaseCmdsImpl.html#a43c7d2663aceb461097c821a8ec8c336":[6,0,2,19,3,18],
-"da/d57/classisc_1_1lease__cmds_1_1LeaseCmdsImpl.html#a46e8d01fd73ba9960fb40956a2c8762c":[6,0,2,19,3,10],
 "da/d57/classisc_1_1lease__cmds_1_1LeaseCmdsImpl.html#a46e8d01fd73ba9960fb40956a2c8762c":[7,0,1,17,3,10],
-"da/d57/classisc_1_1lease__cmds_1_1LeaseCmdsImpl.html#a58fe911b1b49b7cd0d926ddf8a76cd21":[6,0,2,19,3,19],
+"da/d57/classisc_1_1lease__cmds_1_1LeaseCmdsImpl.html#a46e8d01fd73ba9960fb40956a2c8762c":[6,0,2,19,3,10],
 "da/d57/classisc_1_1lease__cmds_1_1LeaseCmdsImpl.html#a58fe911b1b49b7cd0d926ddf8a76cd21":[7,0,1,17,3,19],
-"da/d57/classisc_1_1lease__cmds_1_1LeaseCmdsImpl.html#a5e56c2381f7093100f68122124a0ffc3":[7,0,1,17,3,20],
+"da/d57/classisc_1_1lease__cmds_1_1LeaseCmdsImpl.html#a58fe911b1b49b7cd0d926ddf8a76cd21":[6,0,2,19,3,19],
 "da/d57/classisc_1_1lease__cmds_1_1LeaseCmdsImpl.html#a5e56c2381f7093100f68122124a0ffc3":[6,0,2,19,3,20],
+"da/d57/classisc_1_1lease__cmds_1_1LeaseCmdsImpl.html#a5e56c2381f7093100f68122124a0ffc3":[7,0,1,17,3,20],
 "da/d57/classisc_1_1lease__cmds_1_1LeaseCmdsImpl.html#a717854d77c9e85d05b8ca6e76460c2af":[6,0,2,19,3,13],
 "da/d57/classisc_1_1lease__cmds_1_1LeaseCmdsImpl.html#a717854d77c9e85d05b8ca6e76460c2af":[7,0,1,17,3,13],
 "da/d57/classisc_1_1lease__cmds_1_1LeaseCmdsImpl.html#a7dce77bb0e1a22ba44f0e59528e3965d":[7,0,1,17,3,16],
 "da/d57/classisc_1_1lease__cmds_1_1LeaseCmdsImpl.html#a7dce77bb0e1a22ba44f0e59528e3965d":[6,0,2,19,3,16],
-"da/d57/classisc_1_1lease__cmds_1_1LeaseCmdsImpl.html#a8d73c9bc17308fb98867a18e245c8426":[6,0,2,19,3,11],
 "da/d57/classisc_1_1lease__cmds_1_1LeaseCmdsImpl.html#a8d73c9bc17308fb98867a18e245c8426":[7,0,1,17,3,11],
+"da/d57/classisc_1_1lease__cmds_1_1LeaseCmdsImpl.html#a8d73c9bc17308fb98867a18e245c8426":[6,0,2,19,3,11],
 "da/d57/classisc_1_1lease__cmds_1_1LeaseCmdsImpl.html#a959d04cd46bd6871b1e104cabd069f23":[6,0,2,19,3,14],
 "da/d57/classisc_1_1lease__cmds_1_1LeaseCmdsImpl.html#a959d04cd46bd6871b1e104cabd069f23":[7,0,1,17,3,14],
-"da/d57/classisc_1_1lease__cmds_1_1LeaseCmdsImpl.html#a9d453d6b3001ee52977b1716f2f55e86":[6,0,2,19,3,6],
 "da/d57/classisc_1_1lease__cmds_1_1LeaseCmdsImpl.html#a9d453d6b3001ee52977b1716f2f55e86":[7,0,1,17,3,6],
+"da/d57/classisc_1_1lease__cmds_1_1LeaseCmdsImpl.html#a9d453d6b3001ee52977b1716f2f55e86":[6,0,2,19,3,6],
 "da/d57/classisc_1_1lease__cmds_1_1LeaseCmdsImpl.html#ab7607de1f50e58d46d416f4753f09675":[6,0,2,19,3,4],
 "da/d57/classisc_1_1lease__cmds_1_1LeaseCmdsImpl.html#ab7607de1f50e58d46d416f4753f09675":[7,0,1,17,3,4],
 "da/d57/classisc_1_1lease__cmds_1_1LeaseCmdsImpl.html#ac97ba1608015f298e6f2ea5c8f49f162":[7,0,1,17,3,7],
 "da/d57/classisc_1_1lease__cmds_1_1LeaseCmdsImpl.html#ac97ba1608015f298e6f2ea5c8f49f162":[6,0,2,19,3,7],
-"da/d57/classisc_1_1lease__cmds_1_1LeaseCmdsImpl.html#accc7846dd08f18fe6ebe8350da29981f":[7,0,1,17,3,8],
 "da/d57/classisc_1_1lease__cmds_1_1LeaseCmdsImpl.html#accc7846dd08f18fe6ebe8350da29981f":[6,0,2,19,3,8],
-"da/d57/classisc_1_1lease__cmds_1_1LeaseCmdsImpl.html#aeaf234e3082392458d3cca42b61b3fdf":[6,0,2,19,3,15],
+"da/d57/classisc_1_1lease__cmds_1_1LeaseCmdsImpl.html#accc7846dd08f18fe6ebe8350da29981f":[7,0,1,17,3,8],
 "da/d57/classisc_1_1lease__cmds_1_1LeaseCmdsImpl.html#aeaf234e3082392458d3cca42b61b3fdf":[7,0,1,17,3,15],
-"da/d58/classisc_1_1NotFound.html":[7,0,1,34],
+"da/d57/classisc_1_1lease__cmds_1_1LeaseCmdsImpl.html#aeaf234e3082392458d3cca42b61b3fdf":[6,0,2,19,3,15],
 "da/d58/classisc_1_1NotFound.html":[6,0,2,36],
+"da/d58/classisc_1_1NotFound.html":[7,0,1,34],
 "da/d58/classisc_1_1NotFound.html#a4d10daf971faae45de61d10313efa387":[7,0,1,34,0],
 "da/d58/classisc_1_1NotFound.html#a4d10daf971faae45de61d10313efa387":[6,0,2,36,0],
 "da/d58/classisc_1_1dns_1_1rdata_1_1generic_1_1MINFO.html":[7,0,1,11,1,2,11],
 "da/d58/classisc_1_1dns_1_1rdata_1_1generic_1_1MINFO.html":[6,0,2,13,2,2,11],
-"da/d58/classisc_1_1dns_1_1rdata_1_1generic_1_1MINFO.html#a08bedce1720f3bc67ccd6cb42cf01b12":[6,0,2,13,2,2,11,6],
 "da/d58/classisc_1_1dns_1_1rdata_1_1generic_1_1MINFO.html#a08bedce1720f3bc67ccd6cb42cf01b12":[7,0,1,11,1,2,11,6],
-"da/d58/classisc_1_1dns_1_1rdata_1_1generic_1_1MINFO.html#a371bcf90ef520feca908d61921a7d33f":[6,0,2,13,2,2,11,10],
+"da/d58/classisc_1_1dns_1_1rdata_1_1generic_1_1MINFO.html#a08bedce1720f3bc67ccd6cb42cf01b12":[6,0,2,13,2,2,11,6],
 "da/d58/classisc_1_1dns_1_1rdata_1_1generic_1_1MINFO.html#a371bcf90ef520feca908d61921a7d33f":[7,0,1,11,1,2,11,10],
+"da/d58/classisc_1_1dns_1_1rdata_1_1generic_1_1MINFO.html#a371bcf90ef520feca908d61921a7d33f":[6,0,2,13,2,2,11,10],
 "da/d58/classisc_1_1dns_1_1rdata_1_1generic_1_1MINFO.html#a3d3d781e1848f74b27213b6a28079922":[7,0,1,11,1,2,11,3],
 "da/d58/classisc_1_1dns_1_1rdata_1_1generic_1_1MINFO.html#a3d3d781e1848f74b27213b6a28079922":[6,0,2,13,2,2,11,3],
-"da/d58/classisc_1_1dns_1_1rdata_1_1generic_1_1MINFO.html#a688afc7a29eff4ba671f6bd3d499e43b":[7,0,1,11,1,2,11,1],
 "da/d58/classisc_1_1dns_1_1rdata_1_1generic_1_1MINFO.html#a688afc7a29eff4ba671f6bd3d499e43b":[6,0,2,13,2,2,11,1],
+"da/d58/classisc_1_1dns_1_1rdata_1_1generic_1_1MINFO.html#a688afc7a29eff4ba671f6bd3d499e43b":[7,0,1,11,1,2,11,1],
 "da/d58/classisc_1_1dns_1_1rdata_1_1generic_1_1MINFO.html#a8a4a49a8619b569d399b7b4455a7ef8b":[7,0,1,11,1,2,11,7],
 "da/d58/classisc_1_1dns_1_1rdata_1_1generic_1_1MINFO.html#a8a4a49a8619b569d399b7b4455a7ef8b":[6,0,2,13,2,2,11,7],
-"da/d58/classisc_1_1dns_1_1rdata_1_1generic_1_1MINFO.html#a92ac6c2040f3386409f609ef211a8d6e":[7,0,1,11,1,2,11,9],
 "da/d58/classisc_1_1dns_1_1rdata_1_1generic_1_1MINFO.html#a92ac6c2040f3386409f609ef211a8d6e":[6,0,2,13,2,2,11,9],
+"da/d58/classisc_1_1dns_1_1rdata_1_1generic_1_1MINFO.html#a92ac6c2040f3386409f609ef211a8d6e":[7,0,1,11,1,2,11,9],
 "da/d58/classisc_1_1dns_1_1rdata_1_1generic_1_1MINFO.html#aa2bb978328d50ea46e89377f1b83bb05":[6,0,2,13,2,2,11,2],
 "da/d58/classisc_1_1dns_1_1rdata_1_1generic_1_1MINFO.html#aa2bb978328d50ea46e89377f1b83bb05":[7,0,1,11,1,2,11,2],
-"da/d58/classisc_1_1dns_1_1rdata_1_1generic_1_1MINFO.html#aaf37b748d8595400425ac2f016adf715":[7,0,1,11,1,2,11,5],
 "da/d58/classisc_1_1dns_1_1rdata_1_1generic_1_1MINFO.html#aaf37b748d8595400425ac2f016adf715":[6,0,2,13,2,2,11,5],
-"da/d58/classisc_1_1dns_1_1rdata_1_1generic_1_1MINFO.html#ad0cd224d84a0817c2d3fe72a6fa72204":[6,0,2,13,2,2,11,0],
+"da/d58/classisc_1_1dns_1_1rdata_1_1generic_1_1MINFO.html#aaf37b748d8595400425ac2f016adf715":[7,0,1,11,1,2,11,5],
 "da/d58/classisc_1_1dns_1_1rdata_1_1generic_1_1MINFO.html#ad0cd224d84a0817c2d3fe72a6fa72204":[7,0,1,11,1,2,11,0],
+"da/d58/classisc_1_1dns_1_1rdata_1_1generic_1_1MINFO.html#ad0cd224d84a0817c2d3fe72a6fa72204":[6,0,2,13,2,2,11,0],
 "da/d58/classisc_1_1dns_1_1rdata_1_1generic_1_1MINFO.html#ad50144f490ceea3893e6b84cb30512bd":[6,0,2,13,2,2,11,4],
 "da/d58/classisc_1_1dns_1_1rdata_1_1generic_1_1MINFO.html#ad50144f490ceea3893e6b84cb30512bd":[7,0,1,11,1,2,11,4],
-"da/d58/classisc_1_1dns_1_1rdata_1_1generic_1_1MINFO.html#ae2305634f9bb3cda97dacc1fb2987422":[7,0,1,11,1,2,11,8],
 "da/d58/classisc_1_1dns_1_1rdata_1_1generic_1_1MINFO.html#ae2305634f9bb3cda97dacc1fb2987422":[6,0,2,13,2,2,11,8],
-"da/d58/socketsession_8h.html":[8,0,0,2,24,1,7],
-"da/d58/socketsession_8h_source.html":[8,0,0,2,24,1,7],
-"da/d58/structisc_1_1process_1_1LoggingDestination.html":[6,0,2,24,16],
+"da/d58/classisc_1_1dns_1_1rdata_1_1generic_1_1MINFO.html#ae2305634f9bb3cda97dacc1fb2987422":[7,0,1,11,1,2,11,8],
+"da/d58/socketsession_8h.html":[8,0,0,2,23,1,7],
+"da/d58/socketsession_8h_source.html":[8,0,0,2,23,1,7],
 "da/d58/structisc_1_1process_1_1LoggingDestination.html":[7,0,1,22,16],
-"da/d58/structisc_1_1process_1_1LoggingDestination.html#a2c8abb55667b546620a5d39111d814f4":[6,0,2,24,16,5],
+"da/d58/structisc_1_1process_1_1LoggingDestination.html":[6,0,2,24,16],
 "da/d58/structisc_1_1process_1_1LoggingDestination.html#a2c8abb55667b546620a5d39111d814f4":[7,0,1,22,16,5],
-"da/d58/structisc_1_1process_1_1LoggingDestination.html#a2d71c5f2231745f7b0a9b79c946ad158":[6,0,2,24,16,6],
+"da/d58/structisc_1_1process_1_1LoggingDestination.html#a2c8abb55667b546620a5d39111d814f4":[6,0,2,24,16,5],
 "da/d58/structisc_1_1process_1_1LoggingDestination.html#a2d71c5f2231745f7b0a9b79c946ad158":[7,0,1,22,16,6],
-"da/d58/structisc_1_1process_1_1LoggingDestination.html#a376adfb637244d8d83476db0a02026d7":[6,0,2,24,16,7],
+"da/d58/structisc_1_1process_1_1LoggingDestination.html#a2d71c5f2231745f7b0a9b79c946ad158":[6,0,2,24,16,6],
 "da/d58/structisc_1_1process_1_1LoggingDestination.html#a376adfb637244d8d83476db0a02026d7":[7,0,1,22,16,7],
+"da/d58/structisc_1_1process_1_1LoggingDestination.html#a376adfb637244d8d83476db0a02026d7":[6,0,2,24,16,7],
 "da/d58/structisc_1_1process_1_1LoggingDestination.html#a59f01b3b127fbe448691921bb8b2f38b":[6,0,2,24,16,2],
 "da/d58/structisc_1_1process_1_1LoggingDestination.html#a59f01b3b127fbe448691921bb8b2f38b":[7,0,1,22,16,2],
-"da/d58/structisc_1_1process_1_1LoggingDestination.html#aaf23f05d0abbe928127ae91af33cc0d4":[7,0,1,22,16,0],
 "da/d58/structisc_1_1process_1_1LoggingDestination.html#aaf23f05d0abbe928127ae91af33cc0d4":[6,0,2,24,16,0],
+"da/d58/structisc_1_1process_1_1LoggingDestination.html#aaf23f05d0abbe928127ae91af33cc0d4":[7,0,1,22,16,0],
 "da/d58/structisc_1_1process_1_1LoggingDestination.html#abb1768ae234f4a01e1215b3e1c13a564":[6,0,2,24,16,1],
 "da/d58/structisc_1_1process_1_1LoggingDestination.html#abb1768ae234f4a01e1215b3e1c13a564":[7,0,1,22,16,1],
-"da/d58/structisc_1_1process_1_1LoggingDestination.html#addc28a5ba482f13a7bd62c77d0b556dd":[6,0,2,24,16,4],
 "da/d58/structisc_1_1process_1_1LoggingDestination.html#addc28a5ba482f13a7bd62c77d0b556dd":[7,0,1,22,16,4],
+"da/d58/structisc_1_1process_1_1LoggingDestination.html#addc28a5ba482f13a7bd62c77d0b556dd":[6,0,2,24,16,4],
 "da/d58/structisc_1_1process_1_1LoggingDestination.html#af994ccc42a285da9d282cc120104ee42":[6,0,2,24,16,3],
 "da/d58/structisc_1_1process_1_1LoggingDestination.html#af994ccc42a285da9d282cc120104ee42":[7,0,1,22,16,3],
 "da/d59/namespaceboost_1_1archive.html":[6,0,1,0],
@@ -219,35 +249,5 @@ var NAVTREEINDEX90 =
 "da/d5a/classisc_1_1config_1_1ClientConnectionImpl.html":[7,0,1,4,3],
 "da/d5a/classisc_1_1config_1_1ClientConnectionImpl.html#a1778b63dbefba31e5a6e4b57a9e29052":[6,0,2,5,3,4],
 "da/d5a/classisc_1_1config_1_1ClientConnectionImpl.html#a1778b63dbefba31e5a6e4b57a9e29052":[7,0,1,4,3,4],
-"da/d5a/classisc_1_1config_1_1ClientConnectionImpl.html#a1d66a4205bbea165f01be3c6eb6a67fe":[6,0,2,5,3,7],
-"da/d5a/classisc_1_1config_1_1ClientConnectionImpl.html#a1d66a4205bbea165f01be3c6eb6a67fe":[7,0,1,4,3,7],
-"da/d5a/classisc_1_1config_1_1ClientConnectionImpl.html#a80a54d05bea23f330cf131a6287cc5d3":[7,0,1,4,3,0],
-"da/d5a/classisc_1_1config_1_1ClientConnectionImpl.html#a80a54d05bea23f330cf131a6287cc5d3":[6,0,2,5,3,0],
-"da/d5a/classisc_1_1config_1_1ClientConnectionImpl.html#abc0c57bf406a9fefb9f10c8748d4abba":[6,0,2,5,3,3],
-"da/d5a/classisc_1_1config_1_1ClientConnectionImpl.html#abc0c57bf406a9fefb9f10c8748d4abba":[7,0,1,4,3,3],
-"da/d5a/classisc_1_1config_1_1ClientConnectionImpl.html#ad28e0463462c833ccd96d556d4a19a68":[6,0,2,5,3,2],
-"da/d5a/classisc_1_1config_1_1ClientConnectionImpl.html#ad28e0463462c833ccd96d556d4a19a68":[7,0,1,4,3,2],
-"da/d5a/classisc_1_1config_1_1ClientConnectionImpl.html#ad7c5f384d9a4826f8f8922fc2ecd7681":[6,0,2,5,3,5],
-"da/d5a/classisc_1_1config_1_1ClientConnectionImpl.html#ad7c5f384d9a4826f8f8922fc2ecd7681":[7,0,1,4,3,5],
-"da/d5a/classisc_1_1config_1_1ClientConnectionImpl.html#ade861f9432c2d455ce6cf27f6805e759":[7,0,1,4,3,6],
-"da/d5a/classisc_1_1config_1_1ClientConnectionImpl.html#ade861f9432c2d455ce6cf27f6805e759":[6,0,2,5,3,6],
-"da/d5a/classisc_1_1config_1_1ClientConnectionImpl.html#aefb665c319d862560e59dc0acff97a2d":[6,0,2,5,3,1],
-"da/d5a/classisc_1_1config_1_1ClientConnectionImpl.html#aefb665c319d862560e59dc0acff97a2d":[7,0,1,4,3,1],
-"da/d5b/classisc_1_1dhcp_1_1OptionDataListParser.html":[7,0,1,9,195],
-"da/d5b/classisc_1_1dhcp_1_1OptionDataListParser.html":[6,0,2,11,195],
-"da/d5b/classisc_1_1dhcp_1_1OptionDataListParser.html#a0238e6301b50a2ec1ad4675f963db134":[6,0,2,11,195,5],
-"da/d5b/classisc_1_1dhcp_1_1OptionDataListParser.html#a0238e6301b50a2ec1ad4675f963db134":[7,0,1,9,195,5],
-"da/d5b/classisc_1_1dhcp_1_1OptionDataListParser.html#a4f0893693bb17e579b0255c768b4636b":[7,0,1,9,195,2],
-"da/d5b/classisc_1_1dhcp_1_1OptionDataListParser.html#a4f0893693bb17e579b0255c768b4636b":[6,0,2,11,195,2],
-"da/d5b/classisc_1_1dhcp_1_1OptionDataListParser.html#a7d7258b38ba760740e2f0ea493fe656c":[7,0,1,9,195,1],
-"da/d5b/classisc_1_1dhcp_1_1OptionDataListParser.html#a7d7258b38ba760740e2f0ea493fe656c":[6,0,2,11,195,1],
-"da/d5b/classisc_1_1dhcp_1_1OptionDataListParser.html#aa23b3872123d0e293f741f00219f2289":[6,0,2,11,195,0],
-"da/d5b/classisc_1_1dhcp_1_1OptionDataListParser.html#aa23b3872123d0e293f741f00219f2289":[7,0,1,9,195,0],
-"da/d5b/classisc_1_1dhcp_1_1OptionDataListParser.html#abfef9cb8d6f82078a987b5c37b2fb541":[6,0,2,11,195,4],
-"da/d5b/classisc_1_1dhcp_1_1OptionDataListParser.html#abfef9cb8d6f82078a987b5c37b2fb541":[7,0,1,9,195,4],
-"da/d5b/classisc_1_1dhcp_1_1OptionDataListParser.html#ae15253617b3c2438bdf400084b70c51a":[7,0,1,9,195,3],
-"da/d5b/classisc_1_1dhcp_1_1OptionDataListParser.html#ae15253617b3c2438bdf400084b70c51a":[6,0,2,11,195,3],
-"da/d5b/classisc_1_1log_1_1internal_1_1BufferAppender.html":[7,0,1,19,0,0],
-"da/d5b/classisc_1_1log_1_1internal_1_1BufferAppender.html":[6,0,2,21,0,0],
-"da/d5b/classisc_1_1log_1_1internal_1_1BufferAppender.html#a55c06df27dd748dc190a25e848777fce":[6,0,2,21,0,0,5]
+"da/d5a/classisc_1_1config_1_1ClientConnectionImpl.html#a1d66a4205bbea165f01be3c6eb6a67fe":[7,0,1,4,3,7]
 };
